##

help_outline Help view_list List table_chart Table show_chart Chart
{{vizConfig.data.values.length}} results found. Update Save Chart

Identifier | {{facet.name}} ({{facet.unit_label}})
{{row['id']}} | {{row[facet.field]}}

## How to Search for {{title}}

This faceted browser, configured for {{title}}, contains a search box for each available facet in the panel to the left. Select facet values to filter search results from the knowledge graph. Click UPDATE to refresh search results. For quantitative data, a range slider will appear to enable further refinement of search results.

## How to View Selections

Click an icon in the navigation bar on the top right to view search results.

### view_list List

The List view includes an "infobox" for each search result. Click on the title of the infobox to visit the page for the search results.

### table_chart Table

The Table view includes a column for each facet value selected, and each row corresponds to a search result.

### show_chart Chart

The Chart view lets you plot search results using various visualization strategies for quantitative (Q) or nominal (N) data values:

- Scatter Plot: X Axis (Q), Y Axis (Q), Color (Q/N), Size (Q/N)
- Histogram: X Axis (Q/N) or Y Axis (Q/N)
- Bar Chart: X Axis (Q), Y Axis (N)
- Box Plot: X Axis (Q), Y Axis (N)
- Heatmap: X Axis (Q/N), Y Axis (Q/N)
- Density Plot: X Axis (Q), Y Axis (Q)
- Strip Plot: X Axis (Q), Y Axis (N), Color (Q/N)
- Line Plot: X Axis (Q), Y Axis (Q), Color (Q/N), Size (Q/N)